pub struct FeatureSetFeature { /* private fields */ }Expand description
IFeatureSet feature implementation.
Implementations
Sourceimpl FeatureSetFeature
impl FeatureSetFeature
Sourcepub fn new(device_index: u8, feature_index: u8) -> Self
pub fn new(device_index: u8, feature_index: u8) -> Self
Creates a new feature set feature accessor.
Arguments
device_index- Device index (0xFF for direct)feature_index- Feature index from root feature discovery
Sourcepub async fn get_count(&self, channel: &HidapiChannel) -> Result<u8>
pub async fn get_count(&self, channel: &HidapiChannel) -> Result<u8>
Gets the number of features supported by the device.
Errors
Returns an error if HID++ communication fails.
Sourcepub async fn get_feature_id(
&self,
channel: &HidapiChannel,
index: u8,
) -> Result<FeatureInfo>
pub async fn get_feature_id( &self, channel: &HidapiChannel, index: u8, ) -> Result<FeatureInfo>
Sourcepub async fn enumerate_all(
&self,
channel: &HidapiChannel,
) -> Result<Vec<FeatureInfo>>
pub async fn enumerate_all( &self, channel: &HidapiChannel, ) -> Result<Vec<FeatureInfo>>
Enumerates all features on the device.
Returns a list of all features supported by the device.
Errors
Returns an error if HID++ communication fails.
Sourcepub async fn enumerate_visible(
&self,
channel: &HidapiChannel,
) -> Result<Vec<FeatureInfo>>
pub async fn enumerate_visible( &self, channel: &HidapiChannel, ) -> Result<Vec<FeatureInfo>>
Enumerates only visible features (not hidden or software-hidden).
Errors
Returns an error if HID++ communication fails.